@@ -1,7 +1,7 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-8.
+# Conversion routines for ISO-8859-7.
 # Copyright (C) 2002-2017 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_8;
+package Locale::RecodeData::ISO_8859_7;
 
 use strict;
 
@@ -187,100 +187,100 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0xfffd,
-    0x00a2,
+    0x2018,
+    0x2019,
     0x00a3,
-    0x00a4,
-    0x00a5,
+    0xfffd,
+    0xfffd,
     0x00a6,
     0x00a7,
     0x00a8,
     0x00a9,
-    0x00d7,
+    0xfffd,
     0x00ab,
     0x00ac,
     0x00ad,
-    0x00ae,
-    0x00af,
+    0xfffd,
+    0x2015,
     0x00b0,
     0x00b1,
     0x00b2,
     0x00b3,
-    0x00b4,
-    0x00b5,
-    0x00b6,
+    0x0384,
+    0x0385,
+    0x0386,
     0x00b7,
-    0x00b8,
-    0x00b9,
-    0x00f7,
+    0x0388,
+    0x0389,
+    0x038a,
     0x00bb,
-    0x00bc,
+    0x038c,
     0x00bd,
-    0x00be,
+    0x038e,
+    0x038f,
+    0x0390,
+    0x0391,
+    0x0392,
+    0x0393,
+    0x0394,
+    0x0395,
+    0x0396,
+    0x0397,
+    0x0398,
+    0x0399,
+    0x039a,
+    0x039b,
+    0x039c,
+    0x039d,
+    0x039e,
+    0x039f,
+    0x03a0,
+    0x03a1,
     0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0xfffd,
-    0x2017,
-    0x05d0,
-    0x05d1,
-    0x05d2,
-    0x05d3,
-    0x05d4,
-    0x05d5,
-    0x05d6,
-    0x05d7,
-    0x05d8,
-    0x05d9,
-    0x05da,
-    0x05db,
-    0x05dc,
-    0x05dd,
-    0x05de,
-    0x05df,
-    0x05e0,
-    0x05e1,
-    0x05e2,
-    0x05e3,
-    0x05e4,
-    0x05e5,
-    0x05e6,
-    0x05e7,
-    0x05e8,
-    0x05e9,
-    0x05ea,
-    0xfffd,
-    0xfffd,
-    0x200e,
-    0x200f,
+    0x03a3,
+    0x03a4,
+    0x03a5,
+    0x03a6,
+    0x03a7,
+    0x03a8,
+    0x03a9,
+    0x03aa,
+    0x03ab,
+    0x03ac,
+    0x03ad,
+    0x03ae,
+    0x03af,
+    0x03b0,
+    0x03b1,
+    0x03b2,
+    0x03b3,
+    0x03b4,
+    0x03b5,
+    0x03b6,
+    0x03b7,
+    0x03b8,
+    0x03b9,
+    0x03ba,
+    0x03bb,
+    0x03bc,
+    0x03bd,
+    0x03be,
+    0x03bf,
+    0x03c0,
+    0x03c1,
+    0x03c2,
+    0x03c3,
+    0x03c4,
+    0x03c5,
+    0x03c6,
+    0x03c7,
+    0x03c8,
+    0x03c9,
+    0x03ca,
+    0x03cb,
+    0x03cc,
+    0x03cd,
+    0x03ce,
     0xfffd,
 );
 
@@ -446,100 +446,100 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xef\xbf\xbd",
-    "\xc2\xa2",
+    "\xe2\x80\x98",
+    "\xe2\x80\x99",
     "\xc2\xa3",
-    "\xc2\xa4",
-    "\xc2\xa5",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
     "\xc2\xa6",
     "\xc2\xa7",
     "\xc2\xa8",
     "\xc2\xa9",
-    "\xc3\x97",
+    "\xef\xbf\xbd",
     "\xc2\xab",
     "\xc2\xac",
     "\xc2\xad",
-    "\xc2\xae",
-    "\xc2\xaf",
+    "\xef\xbf\xbd",
+    "\xe2\x80\x95",
     "\xc2\xb0",
     "\xc2\xb1",
     "\xc2\xb2",
     "\xc2\xb3",
-    "\xc2\xb4",
-    "\xc2\xb5",
-    "\xc2\xb6",
+    "\xce\x84",
+    "\xce\x85",
+    "\xce\x86",
     "\xc2\xb7",
-    "\xc2\xb8",
-    "\xc2\xb9",
-    "\xc3\xb7",
+    "\xce\x88",
+    "\xce\x89",
+    "\xce\x8a",
     "\xc2\xbb",
-    "\xc2\xbc",
+    "\xce\x8c",
     "\xc2\xbd",
-    "\xc2\xbe",
+    "\xce\x8e",
+    "\xce\x8f",
+    "\xce\x90",
+    "\xce\x91",
+    "\xce\x92",
+    "\xce\x93",
+    "\xce\x94",
+    "\xce\x95",
+    "\xce\x96",
+    "\xce\x97",
+    "\xce\x98",
+    "\xce\x99",
+    "\xce\x9a",
+    "\xce\x9b",
+    "\xce\x9c",
+    "\xce\x9d",
+    "\xce\x9e",
+    "\xce\x9f",
+    "\xce\xa0",
+    "\xce\xa1",
     "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xe2\x80\x97",
-    "\xd7\x90",
-    "\xd7\x91",
-    "\xd7\x92",
-    "\xd7\x93",
-    "\xd7\x94",
-    "\xd7\x95",
-    "\xd7\x96",
-    "\xd7\x97",
-    "\xd7\x98",
-    "\xd7\x99",
-    "\xd7\x9a",
-    "\xd7\x9b",
-    "\xd7\x9c",
-    "\xd7\x9d",
-    "\xd7\x9e",
-    "\xd7\x9f",
-    "\xd7\xa0",
-    "\xd7\xa1",
-    "\xd7\xa2",
-    "\xd7\xa3",
-    "\xd7\xa4",
-    "\xd7\xa5",
-    "\xd7\xa6",
-    "\xd7\xa7",
-    "\xd7\xa8",
-    "\xd7\xa9",
-    "\xd7\xaa",
-    "\xef\xbf\xbd",
-    "\xef\xbf\xbd",
-    "\xe2\x80\x8e",
-    "\xe2\x80\x8f",
+    "\xce\xa3",
+    "\xce\xa4",
+    "\xce\xa5",
+    "\xce\xa6",
+    "\xce\xa7",
+    "\xce\xa8",
+    "\xce\xa9",
+    "\xce\xaa",
+    "\xce\xab",
+    "\xce\xac",
+    "\xce\xad",
+    "\xce\xae",
+    "\xce\xaf",
+    "\xce\xb0",
+    "\xce\xb1",
+    "\xce\xb2",
+    "\xce\xb3",
+    "\xce\xb4",
+    "\xce\xb5",
+    "\xce\xb6",
+    "\xce\xb7",
+    "\xce\xb8",
+    "\xce\xb9",
+    "\xce\xba",
+    "\xce\xbb",
+    "\xce\xbc",
+    "\xce\xbd",
+    "\xce\xbe",
+    "\xce\xbf",
+    "\xcf\x80",
+    "\xcf\x81",
+    "\xcf\x82",
+    "\xcf\x83",
+    "\xcf\x84",
+    "\xcf\x85",
+    "\xcf\x86",
+    "\xcf\x87",
+    "\xcf\x88",
+    "\xcf\x89",
+    "\xcf\x8a",
+    "\xcf\x8b",
+    "\xcf\x8c",
+    "\xcf\x8d",
+    "\xcf\x8e",
     "\xef\xbf\xbd",
 );
 
@@ -705,10 +705,7 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
-    0x000000a2 => "\xa2",
     0x000000a3 => "\xa3",
-    0x000000a4 => "\xa4",
-    0x000000a5 => "\xa5",
     0x000000a6 => "\xa6",
     0x000000a7 => "\xa7",
     0x000000a8 => "\xa8",
@@ -716,54 +713,87 @@ my %from_ucs4 = (
     0x000000ab => "\xab",
     0x000000ac => "\xac",
     0x000000ad => "\xad",
-    0x000000ae => "\xae",
-    0x000000af => "\xaf",
     0x000000b0 => "\xb0",
     0x000000b1 => "\xb1",
     0x000000b2 => "\xb2",
     0x000000b3 => "\xb3",
-    0x000000b4 => "\xb4",
-    0x000000b5 => "\xb5",
-    0x000000b6 => "\xb6",
     0x000000b7 => "\xb7",
-    0x000000b8 => "\xb8",
-    0x000000b9 => "\xb9",
     0x000000bb => "\xbb",
-    0x000000bc => "\xbc",
     0x000000bd => "\xbd",
-    0x000000be => "\xbe",
-    0x000000d7 => "\xaa",
-    0x000000f7 => "\xba",
-    0x000005d0 => "\xe0",
-    0x000005d1 => "\xe1",
-    0x000005d2 => "\xe2",
-    0x000005d3 => "\xe3",
-    0x000005d4 => "\xe4",
-    0x000005d5 => "\xe5",
-    0x000005d6 => "\xe6",
-    0x000005d7 => "\xe7",
-    0x000005d8 => "\xe8",
-    0x000005d9 => "\xe9",
-    0x000005da => "\xea",
-    0x000005db => "\xeb",
-    0x000005dc => "\xec",
-    0x000005dd => "\xed",
-    0x000005de => "\xee",
-    0x000005df => "\xef",
-    0x000005e0 => "\xf0",
-    0x000005e1 => "\xf1",
-    0x000005e2 => "\xf2",
-    0x000005e3 => "\xf3",
-    0x000005e4 => "\xf4",
-    0x000005e5 => "\xf5",
-    0x000005e6 => "\xf6",
-    0x000005e7 => "\xf7",
-    0x000005e8 => "\xf8",
-    0x000005e9 => "\xf9",
-    0x000005ea => "\xfa",
-    0x0000200e => "\xfd",
-    0x0000200f => "\xfe",
-    0x00002017 => "\xdf",
+    0x00000384 => "\xb4",
+    0x00000385 => "\xb5",
+    0x00000386 => "\xb6",
+    0x00000388 => "\xb8",
+    0x00000389 => "\xb9",
+    0x0000038a => "\xba",
+    0x0000038c => "\xbc",
+    0x0000038e => "\xbe",
+    0x0000038f => "\xbf",
+    0x00000390 => "\xc0",
+    0x00000391 => "\xc1",
+    0x00000392 => "\xc2",
+    0x00000393 => "\xc3",
+    0x00000394 => "\xc4",
+    0x00000395 => "\xc5",
+    0x00000396 => "\xc6",
+    0x00000397 => "\xc7",
+    0x00000398 => "\xc8",
+    0x00000399 => "\xc9",
+    0x0000039a => "\xca",
+    0x0000039b => "\xcb",
+    0x0000039c => "\xcc",
+    0x0000039d => "\xcd",
+    0x0000039e => "\xce",
+    0x0000039f => "\xcf",
+    0x000003a0 => "\xd0",
+    0x000003a1 => "\xd1",
+    0x000003a3 => "\xd3",
+    0x000003a4 => "\xd4",
+    0x000003a5 => "\xd5",
+    0x000003a6 => "\xd6",
+    0x000003a7 => "\xd7",
+    0x000003a8 => "\xd8",
+    0x000003a9 => "\xd9",
+    0x000003aa => "\xda",
+    0x000003ab => "\xdb",
+    0x000003ac => "\xdc",
+    0x000003ad => "\xdd",
+    0x000003ae => "\xde",
+    0x000003af => "\xdf",
+    0x000003b0 => "\xe0",
+    0x000003b1 => "\xe1",
+    0x000003b2 => "\xe2",
+    0x000003b3 => "\xe3",
+    0x000003b4 => "\xe4",
+    0x000003b5 => "\xe5",
+    0x000003b6 => "\xe6",
+    0x000003b7 => "\xe7",
+    0x000003b8 => "\xe8",
+    0x000003b9 => "\xe9",
+    0x000003ba => "\xea",
+    0x000003bb => "\xeb",
+    0x000003bc => "\xec",
+    0x000003bd => "\xed",
+    0x000003be => "\xee",
+    0x000003bf => "\xef",
+    0x000003c0 => "\xf0",
+    0x000003c1 => "\xf1",
+    0x000003c2 => "\xf2",
+    0x000003c3 => "\xf3",
+    0x000003c4 => "\xf4",
+    0x000003c5 => "\xf5",
+    0x000003c6 => "\xf6",
+    0x000003c7 => "\xf7",
+    0x000003c8 => "\xf8",
+    0x000003c9 => "\xf9",
+    0x000003ca => "\xfa",
+    0x000003cb => "\xfb",
+    0x000003cc => "\xfc",
+    0x000003cd => "\xfd",
+    0x000003ce => "\xfe",
+    0x00002015 => "\xaf",
+    0x00002018 => "\xa1",
+    0x00002019 => "\xa2",
 );
 
 sub _recode
@@ -791,7 +821,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_8 - Conversion routines for ISO-8859-8
+Locale::RecodeData::ISO_8859_7 - Conversion routines for ISO-8859-7
 
 =head1 SYNOPSIS
 
@@ -800,7 +830,7 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-8.
+routines for ISO-8859-7.
 
 =head1 COMMENTS
 
@@ -808,10 +838,13 @@ The following comments have been extracted from the original charmap:
 
  version: 1.0
   source: ECMA registry
- alias ISO-IR-138
- alias ISO_8859-8:1988
- alias ISO_8859-8
- alias HEBREW
+ alias ISO-IR-126
+ alias ISO_8859-7:1987
+ alias ISO_8859-7
+ alias ELOT_928
+ alias ECMA-118
+ alias GREEK
+ alias GREEK8
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -984,65 +1017,95 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A2 |  000000A2 | CENT SIGN
+    A1 |  00002018 | LEFT SINGLE QUOTATION MARK
+    A2 |  00002019 | RIGHT SINGLE QUOTATION MARK
     A3 |  000000A3 | POUND SIGN
-    A4 |  000000A4 | CURRENCY SIGN
-    A5 |  000000A5 | YEN SIGN
     A6 |  000000A6 | BROKEN BAR
     A7 |  000000A7 | SECTION SIGN
     A8 |  000000A8 | DIAERESIS
     A9 |  000000A9 | COPYRIGHT SIGN
-    AA |  000000D7 | MULTIPLICATION SIGN
     AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
     AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
-    AE |  000000AE | REGISTERED SIGN
-    AF |  000000AF | MACRON
+    AF |  00002015 | HORIZONTAL BAR
     B0 |  000000B0 | DEGREE SIGN
     B1 |  000000B1 | PLUS-MINUS SIGN
     B2 |  000000B2 | SUPERSCRIPT TWO
     B3 |  000000B3 | SUPERSCRIPT THREE
-    B4 |  000000B4 | ACUTE ACCENT
-    B5 |  000000B5 | MICRO SIGN
-    B6 |  000000B6 | PILCROW SIGN
+    B4 |  00000384 | GREEK TONOS
+    B5 |  00000385 | GREEK DIALYTIKA TONOS
+    B6 |  00000386 | GREEK CAPITAL LETTER ALPHA WITH TONOS
     B7 |  000000B7 | MIDDLE DOT
-    B8 |  000000B8 | CEDILLA
-    B9 |  000000B9 | SUPERSCRIPT ONE
-    BA |  000000F7 | DIVISION SIGN
+    B8 |  00000388 | GREEK CAPITAL LETTER EPSILON WITH TONOS
+    B9 |  00000389 | GREEK CAPITAL LETTER ETA WITH TONOS
+    BA |  0000038A | GREEK CAPITAL LETTER IOTA WITH TONOS
     BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
-    BC |  000000BC | VULGAR FRACTION ONE QUARTER
+    BC |  0000038C | GREEK CAPITAL LETTER OMICRON WITH TONOS
     BD |  000000BD | VULGAR FRACTION ONE HALF
-    BE |  000000BE | VULGAR FRACTION THREE QUARTERS
-    DF |  00002017 | DOUBLE LOW LINE
-    E0 |  000005D0 | HEBREW LETTER ALEF
-    E1 |  000005D1 | HEBREW LETTER BET
-    E2 |  000005D2 | HEBREW LETTER GIMEL
-    E3 |  000005D3 | HEBREW LETTER DALET
-    E4 |  000005D4 | HEBREW LETTER HE
-    E5 |  000005D5 | HEBREW LETTER VAV
-    E6 |  000005D6 | HEBREW LETTER ZAYIN
-    E7 |  000005D7 | HEBREW LETTER HET
-    E8 |  000005D8 | HEBREW LETTER TET
-    E9 |  000005D9 | HEBREW LETTER YOD
-    EA |  000005DA | HEBREW LETTER FINAL KAF
-    EB |  000005DB | HEBREW LETTER KAF
-    EC |  000005DC | HEBREW LETTER LAMED
-    ED |  000005DD | HEBREW LETTER FINAL MEM
-    EE |  000005DE | HEBREW LETTER MEM
-    EF |  000005DF | HEBREW LETTER FINAL NUN
-    F0 |  000005E0 | HEBREW LETTER NUN
-    F1 |  000005E1 | HEBREW LETTER SAMEKH
-    F2 |  000005E2 | HEBREW LETTER AYIN
-    F3 |  000005E3 | HEBREW LETTER FINAL PE
-    F4 |  000005E4 | HEBREW LETTER PE
-    F5 |  000005E5 | HEBREW LETTER FINAL TSADI
-    F6 |  000005E6 | HEBREW LETTER TSADI
-    F7 |  000005E7 | HEBREW LETTER QOF
-    F8 |  000005E8 | HEBREW LETTER RESH
-    F9 |  000005E9 | HEBREW LETTER SHIN
-    FA |  000005EA | HEBREW LETTER TAV
-    FD |  0000200E | LEFT-TO-RIGHT MARK
-    FE |  0000200F | RIGHT-TO-LEFT MARK
+    BE |  0000038E | GREEK CAPITAL LETTER UPSILON WITH TONOS
+    BF |  0000038F | GREEK CAPITAL LETTER OMEGA WITH TONOS
+    C0 |  00000390 | GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS
+    C1 |  00000391 | GREEK CAPITAL LETTER ALPHA
+    C2 |  00000392 | GREEK CAPITAL LETTER BETA
+    C3 |  00000393 | GREEK CAPITAL LETTER GAMMA
+    C4 |  00000394 | GREEK CAPITAL LETTER DELTA
+    C5 |  00000395 | GREEK CAPITAL LETTER EPSILON
+    C6 |  00000396 | GREEK CAPITAL LETTER ZETA
+    C7 |  00000397 | GREEK CAPITAL LETTER ETA
+    C8 |  00000398 | GREEK CAPITAL LETTER THETA
+    C9 |  00000399 | GREEK CAPITAL LETTER IOTA
+    CA |  0000039A | GREEK CAPITAL LETTER KAPPA
+    CB |  0000039B | GREEK CAPITAL LETTER LAMDA
+    CC |  0000039C | GREEK CAPITAL LETTER MU
+    CD |  0000039D | GREEK CAPITAL LETTER NU
+    CE |  0000039E | GREEK CAPITAL LETTER XI
+    CF |  0000039F | GREEK CAPITAL LETTER OMICRON
+    D0 |  000003A0 | GREEK CAPITAL LETTER PI
+    D1 |  000003A1 | GREEK CAPITAL LETTER RHO
+    D3 |  000003A3 | GREEK CAPITAL LETTER SIGMA
+    D4 |  000003A4 | GREEK CAPITAL LETTER TAU
+    D5 |  000003A5 | GREEK CAPITAL LETTER UPSILON
+    D6 |  000003A6 | GREEK CAPITAL LETTER PHI
+    D7 |  000003A7 | GREEK CAPITAL LETTER CHI
+    D8 |  000003A8 | GREEK CAPITAL LETTER PSI
+    D9 |  000003A9 | GREEK CAPITAL LETTER OMEGA
+    DA |  000003AA | GREEK CAPITAL LETTER IOTA WITH DIALYTIKA
+    DB |  000003AB | GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA
+    DC |  000003AC | GREEK SMALL LETTER ALPHA WITH TONOS
+    DD |  000003AD | GREEK SMALL LETTER EPSILON WITH TONOS
+    DE |  000003AE | GREEK SMALL LETTER ETA WITH TONOS
+    DF |  000003AF | GREEK SMALL LETTER IOTA WITH TONOS
+    E0 |  000003B0 | GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS
+    E1 |  000003B1 | GREEK SMALL LETTER ALPHA
+    E2 |  000003B2 | GREEK SMALL LETTER BETA
+    E3 |  000003B3 | GREEK SMALL LETTER GAMMA
+    E4 |  000003B4 | GREEK SMALL LETTER DELTA
+    E5 |  000003B5 | GREEK SMALL LETTER EPSILON
+    E6 |  000003B6 | GREEK SMALL LETTER ZETA
+    E7 |  000003B7 | GREEK SMALL LETTER ETA
+    E8 |  000003B8 | GREEK SMALL LETTER THETA
+    E9 |  000003B9 | GREEK SMALL LETTER IOTA
+    EA |  000003BA | GREEK SMALL LETTER KAPPA
+    EB |  000003BB | GREEK SMALL LETTER LAMDA
+    EC |  000003BC | GREEK SMALL LETTER MU
+    ED |  000003BD | GREEK SMALL LETTER NU
+    EE |  000003BE | GREEK SMALL LETTER XI
+    EF |  000003BF | GREEK SMALL LETTER OMICRON
+    F0 |  000003C0 | GREEK SMALL LETTER PI
+    F1 |  000003C1 | GREEK SMALL LETTER RHO
+    F2 |  000003C2 | GREEK SMALL LETTER FINAL SIGMA
+    F3 |  000003C3 | GREEK SMALL LETTER SIGMA
+    F4 |  000003C4 | GREEK SMALL LETTER TAU
+    F5 |  000003C5 | GREEK SMALL LETTER UPSILON
+    F6 |  000003C6 | GREEK SMALL LETTER PHI
+    F7 |  000003C7 | GREEK SMALL LETTER CHI
+    F8 |  000003C8 | GREEK SMALL LETTER PSI
+    F9 |  000003C9 | GREEK SMALL LETTER OMEGA
+    FA |  000003CA | GREEK SMALL LETTER IOTA WITH DIALYTIKA
+    FB |  000003CB | GREEK SMALL LETTER UPSILON WITH DIALYTIKA
+    FC |  000003CC | GREEK SMALL LETTER OMICRON WITH TONOS
+    FD |  000003CD | GREEK SMALL LETTER UPSILON WITH TONOS
+    FE |  000003CE | GREEK SMALL LETTER OMEGA WITH TONOS
 
 
 =head1 AUTHOR
